summaryrefslogtreecommitdiff
path: root/chip/npcx/lpc.c
diff options
context:
space:
mode:
Diffstat (limited to 'chip/npcx/lpc.c')
-rw-r--r--chip/npcx/lpc.c7
1 files changed, 3 insertions, 4 deletions
diff --git a/chip/npcx/lpc.c b/chip/npcx/lpc.c
index af945c820a..e29ed6c57b 100644
--- a/chip/npcx/lpc.c
+++ b/chip/npcx/lpc.c
@@ -6,6 +6,7 @@
/* LPC module for Chrome EC */
#include "acpi.h"
+#include "chipset.h"
#include "clock.h"
#include "common.h"
#include "console.h"
@@ -756,11 +757,9 @@ void lpc_lreset_pltrst_handler(void)
/* Clear pending bit of WUI */
SET_BIT(NPCX_WKPCL(MIWU_TABLE_0 , MIWU_GROUP_5), 7);
-#ifdef GPIO_PCH_RSMRST_L
- /* Ignore PLTRST# from SOC unless RSMRST# to soc is deasserted */
- if (!gpio_get_level(GPIO_PCH_RSMRST_L))
+ /* Ignore PLTRST# from SOC if it is not valid */
+ if (chipset_pltrst_is_valid && !chipset_pltrst_is_valid())
return;
-#endif
ccprintf("[%T PLTRST deasserted]\n");